@@ -1,6 +1,8 @@
-$VERSION = '0.06';
-
 package Win32::SDDL;
+# ABSTRACT: Parser for the Windows Security Descriptor Definition Language (SDDL)
+use strict;
+use warnings;
+our $VERSION = '0.07';
 use Win32::OLE;
 
 my $CONSTANTS = {};
@@ -16,7 +18,7 @@ sub new{
     $self->{SDString} = '';
     $self->{ACL} = {};
     _initialize($self->{Type},$CONSTANTS,$TRUSTEE_CONSTANTS) or die("Unable to initialize Constants!\n");
-    bless($self) || die("Unable to bless '$self'!\n");
+    bless($self, $class) || die("Unable to bless '$self'!\n");
     return $self;
 }
 
@@ -43,7 +45,7 @@ sub Import{
     #Check that the SDDL string is in a valid format
     my @rights = $self->{SDString} =~ /\((.*?)\)/g;
     unless($self->{SDString}){
-        return undef;
+        return;     # Returns empty list (list context) or undef (scalar context)
     }
 
     #Cycle through the ACEs
@@ -209,6 +211,8 @@ sub _translateSID{
 }
 
 package Win32::SDDL::ACE;
+use strict;
+use warnings;
 
 sub new{
     my $class = shift;
@@ -233,7 +237,8 @@ sub new{
         }
 
         #Translate the ACE flags
-        my @flags = ($self->{_flags} =~ /\w\w/g) if $self->{_flags};
+        my @flags;
+        @flags = ($self->{_flags} =~ /\w\w/g) if $self->{_flags};
         foreach my $flag(@flags){
             if($const{$flag}){
                 $flag = $const{$flag};
@@ -249,17 +254,24 @@ sub new{
             $trustees{$self->{Trustee}} = $account;
             $self->{Trustee} = $account;
         }
-        bless($self) || die("Unable to bless '$self'!\n");
+        bless($self,$class) || die("Unable to bless '$self'!\n");
         return $self;
 }
 
 
 1;
 
+__END__
+
+=pod
 
 =head1 NAME
 
-Win32::SDDL - SDDL parsing module for Windows
+Win32::SDDL - Parser for the Windows Security Descriptor Definition Language (SDDL)
+
+=head1 VERSION
+
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -278,7 +290,6 @@ Win32::SDDL - SDDL parsing module for Windows
 
     print scalar( @{$sddl->{ACL}} )." entries found.\n";
 
-
 =head1 DESCRIPTION
 
 This module was created to aid in interpreting SDDL strings commonly used in
@@ -366,39 +377,131 @@ The Trustee name.
 
 =head1 UPDATE HISTORY
 
+=over
+
 =item See the Changes file.
 
-=head1 BUGS/CHANGES NEEDED
-
-=over 5
-
-=item Replace Win32::OLE Dependency
-
-Right now I'm using WMI to translate SIDs to account names.  I would like to
-find a way to import the Win32 API with a minimal footprint to reduce the size
-of the module for people who distribute packaged executables and archives of
-their scripts.
-
-=item B<Have any questions/suggestions?>
-
-Please contact me if you have any requests or suggestions.
-
 =back
 
+=head1 FORTHCOMING CHANGES
+
+=over 5
+
+=item Modular SID Translation
+
+As originally written, the module uses WMI to translate SIDs to account names.
+The intention is to allow support for arbitrary translators, with the following
+to be provided by this module: WMI, native API call, LDAP, Offline.
+
+=back
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=Win32-SDDL or by email to
+bug-win32-sddl at rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Win32::SDDL
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Win32-SDDL>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Win32-SDDL>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Win32-SDDL>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Win32-SDDL>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Win32::SDDL>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-win32-sddl at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-SDDL>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/richardleach/Win32-SDDL>
+
+  git clone https://github.com/richardleach/Win32-SDDL.git
+
 =head1 SEE ALSO
 
-L<http://windowssdk.msdn.microsoft.com/en-us/library/ms723280.aspx>
+Please see those modules/websites for more information related to this module.
 
-=head1 COPYRIGHT
+=over 4
 
-Copyright 2006 Tim Johnson
+=item *
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+L<http://windowssdk.msdn.microsoft.com/en-us/library/ms723280.aspx|http://windowssdk.msdn.microsoft.com/en-us/library/ms723280.aspx>
+
+=back
 
 =head1 AUTHOR
 
-Tim Johnson <tojo2000@tojo2000.com>
+Tim Johnson, Richard Leach
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Richard Leach.
+This software is copyright (c) 2006 by Tim Johnson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
